<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Program_Name</source>
        <translation>Program_Name</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="46"/>
        <source>Quit application</source>
        <translation>Esci dall&apos;applicazione</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="49"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="56"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="88"/>
        <source>Display help </source>
        <translation>Visualizza la guida</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="91"/>
        <source>Help</source>
        <translation>Aiuto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="98"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="114"/>
        <source>Back</source>
        <translation>Indietro</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="172"/>
        <source>Next</source>
        <translation>Avanti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="198"/>
        <source>About this application</source>
        <translation>Informazioni su questa applicazione</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="201"/>
        <source>About...</source>
        <translation>Info</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="208"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="224"/>
        <source>View Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="259"/>
        <location filename="../mainwindow.cpp" line="517"/>
        <location filename="../mainwindow.cpp" line="538"/>
        <source>Select ISO</source>
        <translation>Seleziona un file ISO</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="270"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select Target USB Device&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Seleziona il dispositivo USB di destinazione&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="280"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select ISO file&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Seleziona un file ISO&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="309"/>
        <source>Advanced Options</source>
        <translation>Opzioni avanzate</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="327"/>
        <source>Make the ext4 filesystem even if one exists</source>
        <translation>Crea il filesystem ext4, anche se ne esiste già uno</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="334"/>
        <source>Save the original boot directory when updating a live-usb</source>
        <translation>Salva la directory boot quando si aggiorna una USB-Live</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="341"/>
        <source>Use gpt partitioning instead of msdos</source>
        <translation>Usa il partizionamento GPT invece di quello MS-DOS</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="344"/>
        <source>GPT partitioning</source>
        <translation>Partizionamento GPT</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="351"/>
        <source>Update (only update an existing live-usb)</source>
        <translation>Aggiorna (solo aggiorna una USB Live esistente)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="358"/>
        <source>Don&apos;t replace syslinux files</source>
        <translation>Non sostituire i file di syslinux</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="361"/>
        <source>Keep syslinux files</source>
        <translation>Mantieni i file di syslinux</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="368"/>
        <source>Ignore USB/removable check</source>
        <translation>Ignora il controllo dispositivi rimovibili/USB</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="375"/>
        <source>Temporarily disable automounting</source>
        <translation>Disabilita temporaneamente il montaggio automatico</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="385"/>
        <source>Set pmbr_boot disk flag (won&apos;t boot via UEFI)</source>
        <translation>Imposta il flag del disco come pmbr_boot (non effettua il boot tramite UEFI)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="392"/>
        <source>Don&apos;t use fuseiso to mount iso files</source>
        <translation>Non usare fuseiso per il montaggio dei file iso</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="418"/>
        <source>Size of ESP (uefi) partition:</source>
        <translation>Dimensione della partizione ESP (UEFI):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="438"/>
        <source>Verbosity (less to more):</source>
        <translation>Dettagli (da meno a più):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="477"/>
        <source>vfat</source>
        <translation>vfat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="482"/>
        <source>exfat</source>
        <translation>exfat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="487"/>
        <source>ext4</source>
        <translation>ext4</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="492"/>
        <source>ntfs</source>
        <translation>ntfs</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="513"/>
        <source>Make separate data partition (percent)</source>
        <translation>Creare una partizione dati separata (percentuale)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="520"/>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="530"/>
        <source>Refresh drive list</source>
        <translation>Aggiorna l&apos;elenco delle unità</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="544"/>
        <location filename="../mainwindow.cpp" line="462"/>
        <source>Show advanced options</source>
        <translation>Mostra le opzioni avanzate</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="564"/>
        <source>Mode</source>
        <translation>Modalità</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="579"/>
        <source>Full-featured mode - writable Li&amp;veUSB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="592"/>
        <source>Image &amp;mode - read-only LiveUSB (dd)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Full-featured mode - writable LiveUSB</source>
        <translation type="vanished">Modalità full-optional - LiveUSB scrivibile</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="589"/>
        <source>Read-only, cannot be used with persistency</source>
        <translation>Sola lettura, non può essere utilizzato con la persistenza</translation>
    </message>
    <message>
        <source>Image mode - read-only LiveUSB (dd)</source>
        <translation type="vanished">Modalità Immagine - LiveUSB in sola-lettura (dd)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="606"/>
        <source>For distros other than antiX/MX use image mode (dd).</source>
        <translation>Per distro diverse da antiX/MX usa Modalità Immagine (dd)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="654"/>
        <source>Options</source>
        <translation>Opzioni</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="689"/>
        <source>Percent of USB-device to use:</source>
        <translation>Percentuale da usare del dispositivo USB:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="696"/>
        <source>Label ext partition:</source>
        <translation>Etichetta della partizione ext:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="744"/>
        <source>Don&apos;t run commands that affect the usb device</source>
        <translation>Non eseguire i comandi che hanno effetto sul dispositivo USB</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="747"/>
        <source>Dry run (no change to system)</source>
        <translation>Fai una prova (nessuna modifica al sistema)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="754"/>
        <source>clone from a mounted live-usb or iso-file.</source>
        <translation>Clona da una USB Live montata, o da un file ISO</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="757"/>
        <source>Clone an existing live system</source>
        <translation>Clona un sistema &apos;Live&apos; esistente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="764"/>
        <source>Set up to boot from an encrypted partition, will prompt for pass phrase on first boot</source>
        <translation>Imposta il boot da una partizione crittografata. Verrà richiesta la passphrase al primo avvio</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="767"/>
        <source>Encrypt</source>
        <translation>Crittografa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="774"/>
        <source>Clone running live system</source>
        <translation>Clona il sistema &apos;Live&apos; in esecuzione</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="72"/>
        <source>Confirmation</source>
        <translation>Conferma</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="72"/>
        <source>Target device %1 is larger than %2 GB. Do you wish to proceed?</source>
        <translation>Il dispositivo di destinazione 1 è più grande di 2 GB. Vuoi procedere?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="108"/>
        <location filename="../mainwindow.cpp" line="308"/>
        <location filename="../mainwindow.cpp" line="447"/>
        <source>Failure</source>
        <translation>Operazione non riuscita</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="108"/>
        <source>Source and destination are on the same device, please select again.</source>
        <translation>Sorgente e destinazione sono sullo stesso dispositivo, seleziona di nuovo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="140"/>
        <source>Writing %1 using &apos;dd&apos; command to /dev/%2,

Please wait until the the process is completed</source>
        <translation>Scrittura di %1 su /dev/%2, utilizzando il comando &apos;dd&apos;,

Attendi fino al completamento del processo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="306"/>
        <source>Success</source>
        <translation>Operazione riuscita</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="306"/>
        <source>LiveUSB creation successful!</source>
        <translation>La creazione della USB Live ha avuto successo!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="308"/>
        <source>Error encountered in the LiveUSB creation process</source>
        <translation>Riscontrato un errore durante il processo di creazione della USB Live</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="368"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="368"/>
        <source>Please select a USB device to write to</source>
        <translation>Seleziona un dispositivo USB per la scrittura</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="371"/>
        <location filename="../mainwindow.cpp" line="531"/>
        <source>clone</source>
        <translation>Clona</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="407"/>
        <source>About %1</source>
        <translation>Circa %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="408"/>
        <source>Version: </source>
        <translation>Versione: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="409"/>
        <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
        <translation>Programma per la creazione di una USB Live da un file ISO, da un&apos;altra Live USB o da un sistema &apos;live&apos; in esecuzione.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="411"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="412"/>
        <source>%1 License</source>
        <translation>%1 Licenza</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="420"/>
        <source>%1 Help</source>
        <translation>%1 Aiuto</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="431"/>
        <source>Select an ISO file to write to the USB drive</source>
        <translation>Seleziona un file ISO da scrivere nell&apos;unità USB</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="431"/>
        <source>ISO Files (*.iso);;All Files (*.*)</source>
        <translation>File ISO (*.iso); Tutti i file (*.*)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="441"/>
        <location filename="../mainwindow.cpp" line="513"/>
        <source>Select Source Directory</source>
        <translation>Seleziona la directory sorgente</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="447"/>
        <source>Could not find %1/antiX/linuxfs file</source>
        <translation>Impossibile trovare il file %1/antiX/linuxfs</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="468"/>
        <source>Hide advanced options</source>
        <translation>Nascondi le opzioni avanzate</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="512"/>
        <location filename="../mainwindow.cpp" line="529"/>
        <source>Select Source</source>
        <translation>Seleziona la sorgente</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="516"/>
        <location filename="../mainwindow.cpp" line="536"/>
        <source>Select ISO file</source>
        <translation>Seleziona un file ISO</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="619"/>
        <source>Could not find a log file at: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../about.cpp" line="32"/>
        <source>License</source>
        <translation>Licenza</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="33"/>
        <location filename="../about.cpp" line="43"/>
        <source>Changelog</source>
        <translation>Registro delle modifiche</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <source>&amp;Close</source>
        <translation>&amp;Chiudi</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="vanished">Errore</translation>
    </message>
    <message>
        <source>You must run this program as root.</source>
        <translation type="vanished">Devi eseguire questo programma come utente root</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="47"/>
        <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
        <translation type="unfinished">Programma per la creazione di una USB Live da un file ISO, da un&apos;altra Live USB o da un sistema &apos;live&apos; in esecuzione.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>filename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>Name of .iso file to open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>[filename]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="78"/>
        <source>version:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
